@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -27,6 +27,7 @@
 #include "lokalizesubwindowbase.h"
 
 #include <KMainWindow>
+#include <KProcess>
 
 #include <KXMLGUIClient>
 
@@ -46,23 +47,30 @@ class ProjectTab: public LokalizeSubwindowBase2
     //qdbuscpp2xml -m -s projecttab.h -o org.kde.lokalize.ProjectOverview.xml
 
 public:
-    ProjectTab(QWidget *parent);
-    ~ProjectTab();
+    explicit ProjectTab(QWidget *parent);
+    ~ProjectTab() override;
 
-    void contextMenuEvent(QContextMenuEvent *event);
+    void contextMenuEvent(QContextMenuEvent *event) override;
 
-    void hideDocks(){};
-    void showDocks(){};
-    KXMLGUIClient* guiClient(){return (KXMLGUIClient*)this;}
-    QString currentFilePath();
+    void hideDocks() override {}
+    void showDocks() override {}
+    KXMLGUIClient* guiClient() override
+    {
+        return (KXMLGUIClient*)this;
+    }
+    QString currentFilePath() override;
 
-    int unitsCount(){return m_currentUnitsCount;}
+    int unitsCount()
+    {
+        return m_currentUnitsCount;
+    }
     void setLegacyUnitsCount(int to);
 
 signals:
-    void projectOpenRequested(QString path=QString());
+    void projectOpenRequested(QString path);
+    void projectOpenRequested();
 
-    void fileOpenRequested(const QString&);
+    void fileOpenRequested(const QString&, const bool setAsActive);
 
     void searchRequested(const QStringList&);
     void replaceRequested(const QStringList&);
@@ -82,7 +90,8 @@ private slots:
     void setFilterRegExp();
     void setFocus();
     void scanFilesToTM();
-    void searchInFiles(bool templ=false);
+    void pologyOnFiles();
+    void searchInFiles(bool templ = false);
     void searchInFilesInclTempl();
     void openFile();
     void findInFiles();
@@ -99,17 +108,23 @@ private slots:
     void gotoNextTemplateOnly();
     void gotoPrevTransOnly();
     void gotoNextTransOnly();
+    void toggleTranslatedFiles();
 
     void updateStatusBar(int fuzzy = 0, int translated = 0, int untranslated = 0, bool done = false);
     void initStatusBarProgress();
 
+    void pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus);
+
 private:
     ProjectWidget* m_browser;
     QLineEdit* m_filterEdit;
     QProgressBar* m_progressBar;
-    
+
     QStackedLayout *m_stackedLayout;
 
+    KProcess* m_pologyProcess;
+    bool m_pologyProcessInProgress;
+
     int m_legacyUnitsCount, m_currentUnitsCount;
 };
 
